@@ -25,8 +25,10 @@ function _aws_cdk_aws_codestarnotifications_NotificationRuleProps(p) {
     try {
         if (!visitedObjects.has(p.source))
             _aws_cdk_aws_codestarnotifications_INotificationRuleSource(p.source);
-        if (!visitedObjects.has(p.targets))
-            _aws_cdk_aws_codestarnotifications_INotificationRuleTarget(p.targets);
+        if (p.targets != null)
+            for (const o of p.targets)
+                if (!visitedObjects.has(o))
+                    _aws_cdk_aws_codestarnotifications_INotificationRuleTarget(o);
         if (!visitedObjects.has(p.detailType))
             _aws_cdk_aws_codestarnotifications_DetailType(p.detailType);
     }
